import * as React from 'react';
import Head from 'next/head';
import { AppProps } from 'next/app';
import { AppCacheProvider } from '@mui/material-nextjs/v14-pagesRouter';
import { ThemeProvider } from '@mui/material/styles';
import CssBaseline from '@mui/material/CssBaseline';
import theme from '../src/theme';

// ** Store Imports
import { Provider } from 'react-redux'
import { store } from '../store'
import { AuthProvider } from '../contexts/AuthContext';

export default function MyApp(props: AppProps) {
  const { Component, pageProps } = props;
  return (
      <Provider store={store}>
        <AppCacheProvider {...props}>
          <Head>
            <meta name="viewport" content="initial-scale=1, width=device-width" />
          </Head>
          <ThemeProvider theme={theme}>
            {/* CssBaseline kickstart an elegant, consistent, and simple baseline to build upon. */}
            <CssBaseline />
            <AuthProvider>
              <Component {...pageProps} />
            </AuthProvider>
          </ThemeProvider>
        </AppCacheProvider>
      </Provider>
  );
}
